#!/bin/sh

# source code is https://github.com/arvidn/libtorrent

git clone https://github.com/paullouisageneau/boost-asio-gnutls deps/asio-gnutls
cd deps/asio-gnutls && git -c advice.detachedHead=false checkout a57d4d3
rm -rf .*
cd ../..

git clone https://github.com/arvidn/try_signal deps/try_signal
cd deps/try_signal && git -c advice.detachedHead=false checkout  105cce5
rm -rf .*
cd ../..

git clone https://github.com/paullouisageneau/libdatachannel deps/libdatachannel
cd deps/libdatachannel && git -c advice.detachedHead=false checkout a02b751
rm -rf .*
cd ../..

git clone https://github.com/paullouisageneau/libjuice deps/libdatachannel/deps/libjuice
cd deps/libdatachannel/deps/libjuice && git -c advice.detachedHead=false checkout 5948a41
rm -rf .*
cd ../../../..

git clone https://github.com/SergiusTheBest/plog deps/libdatachannel/deps/plog
cd deps/libdatachannel/deps/plog && git -c advice.detachedHead=false checkout 94899e0
rm -rf .*
cd ../../../..

git clone https://github.com/paullouisageneau/usrsctp deps/libdatachannel/deps/usrsctp
cd deps/libdatachannel/usrsctp && git -c advice.detachedHead=false checkout fec583d
m -rf .*
cd ../../../..

git clone https://github.com/arvidn/libsimulator.git simulation/libsimulator
cd simulation/libsimulator
rm -rf .*
cd ../..
